/*

 Arduino TFT Bitmap Logo example

 This example reads an image file from a micro-SD card
 and draws it on the screen, at random locations.

 In this sketch, the Arduino logo is read from a micro-SD card.
 There is a .bmp file included with this sketch.
 - open the sketch folder (Ctrl-K or Cmd-K)
 - copy the "arduino.bmp" file to a micro-SD
 - put the SD into the SD slot of the Arduino TFT module.

 This example code is in the public domain.

 Created 19 April 2013 by Enrico Gueli

 http://arduino.cc/en/Tutorial/TFTBitmapLogo

 */

// include the necessary libraries
#include <SPI.h>
#include <SD.h>
#include <TFT.h>  // Arduino LCD library
#include "D:\Projekte\Arduino\TFT\TFTBitmapLogo\a\che_L.c"
#include "D:\Projekte\Arduino\TFT\TFTBitmapLogo\a\che_R.c"
#include "D:\Projekte\Arduino\TFT\TFTBitmapLogo\a\arduino.c"

// pin definition for the MEGA256
#define sd_cs    53
#define lcd_cs   49
#define lcd_dc   47
#define lcd_rst  48
#define lcd_bl   46

// pin definition for the Uno
//#define sd_cs  4
//#define lcd_cs 10
//#define dc     9
//#define rst    8

// pin definition for the Leonardo
//#define sd_cs  8
//#define lcd_cs 7
//#define dc     0
//#define rst    1

TFT TFTscreen = TFT(lcd_cs, lcd_dc, lcd_rst);

// this variable represents the image to be drawn on screen
PImage logo;

void setup() {

  // init IOs
  pinMode(sd_cs, OUTPUT);
  pinMode(lcd_bl, OUTPUT);
  digitalWrite(lcd_bl, LOW);    // backlight ON

  // initialize the GLCD and show a message
  // asking the user to open the serial line
  TFTscreen.begin();
  TFTscreen.background(255, 255, 255);

  TFTscreen.stroke(0, 0, 255);
  TFTscreen.println();
  TFTscreen.println(F("Arduino TFT Bitmap Example"));
  TFTscreen.stroke(0, 0, 0);
  TFTscreen.println(F("Open serial monitor"));
  TFTscreen.println(F("to run the sketch"));
  delay(5000);

  // initialize the serial port: it will be used to
  // print some diagnostic info
  Serial.begin(9600);
  while (!Serial) {
    // wait for serial line to be ready
  }

  // clear the GLCD screen before starting
  TFTscreen.background(255, 255, 255);

  // try to access the SD card. If that fails (e.g.
  // no card present), the setup process will stop.
  Serial.print(F("Initializing SD card..."));
  if (!SD.begin(sd_cs)) {
    Serial.println(F("failed!"));
    return;
  }
  Serial.println(F("OK!"));

  // initialize and clear the GLCD screen
  TFTscreen.begin();
  TFTscreen.background(255, 255, 255);
}

void image_test(char* fname) {
  int t_start, t_end;

  // now that the SD card can be access, try to load the
  // image file.
  logo = TFTscreen.loadImage(fname);
  if (!logo.isValid()) {
    Serial.print(F("error while loading "));
    Serial.println(fname);
    return;
  }

  Serial.println(F("drawing image"));

  // get a random location where to draw the image.
  // To avoid the image to be draw outside the screen,
  // take into account the image size.
  int x = random(TFTscreen.width() - logo.width());
  int y = random(TFTscreen.height() - logo.height());

  t_start = millis();
  // draw the image to the screen
  TFTscreen.image(logo, x, y);
  t_end = millis();
  Serial.print(F("image load time is ")); Serial.print(t_end - t_start); Serial.println(F("ms"));
}

void loop() {
  int i, r, g, b, x, y;
  int t_start, t_end;

  logo = TFTscreen.loadImageFlash(arduino);
  if (!logo.isValid()) {
    Serial.println(F("flash data invalid"));
    return;
  }

  Serial.println(F("drawing image"));

  // get a random location where to draw the image.
  // To avoid the image to be draw outside the screen,
  // take into account the image size.
  t_start = millis();
  for (i=0; i<100; i++) {
    x = random(TFTscreen.width() - logo.width());
    y = random(TFTscreen.height() - logo.height());

    // draw the image to the screen
    TFTscreen.image(logo, x, y);
    
  }  
  t_end = millis();
  Serial.print(F("image load time is ")); Serial.print((t_end - t_start)/100); Serial.println(F("ms"));
  delay(2000);

  logo = TFTscreen.loadImageFlash(che_L);
  if (!logo.isValid()) {
    Serial.println(F("flash data invalid"));
    return;
  }

  Serial.println(F("drawing image"));

  x = 0;
  y = 0;

  t_start = millis();
  // draw the image to the screen
  TFTscreen.image(logo, x, y);
  t_end = millis();
  Serial.print(F("image load time is ")); Serial.print(t_end - t_start); Serial.println(F("ms"));

  logo = TFTscreen.loadImageFlash(che_R);
  if (!logo.isValid()) {
    Serial.println(F("flash data invalid"));
    return;
  }

  Serial.println(F("drawing image"));

  x = 80;
  y = 0;

  t_start = millis();
  // draw the image to the screen
  TFTscreen.image(logo, x, y);
  t_end = millis();
  Serial.print(F("image load time is ")); Serial.print(t_end - t_start); Serial.println(F("ms"));

  delay(2000);

  TFTscreen.background(255, 255, 255);
  image_test("ino_24.bmp");
  delay(2000);

  TFTscreen.background(255, 255, 255);
  image_test("ino_16.bmp");
  delay(2000);

  TFTscreen.background(255, 255, 255);
  image_test("che_24.bmp");
  delay(2000);

  TFTscreen.background(255, 255, 255);
  image_test("che_16.bmp");
  delay(2000);

   // random dots

   //TFTscreen.background(255, 255, 255);
   for (i=0; i<20000; i++ ) {
     r=random(256);
     g=random(256);
     b=random(256);
     x=random(160);
     y=random(128);
     TFTscreen.stroke(r,g,b);
     TFTscreen.point(x,y);
   }

    delay(2000);


    // gey scale

    for (i=0; i<128; i++) {
      TFTscreen.stroke(2*i,2*i,2*i);
      TFTscreen.line(0,i,160,i);
    }

    delay(2000);

     // red scale
    for (i=0; i<128; i++) {
      TFTscreen.stroke(2*i,0,0);
      TFTscreen.line(0,i,160,i);
    }

    delay(2000);


     // green scale
    for (i=0; i<128; i++) {
      TFTscreen.stroke(0,2*i,0);
      TFTscreen.line(0,i,160,i);
    }

    delay(2000);

    // blue scale
    for (i=0; i<128; i++) {
      TFTscreen.stroke(0,0,2*i);
      TFTscreen.line(0,i,160,i);
    }

    delay(2000);

   // some text
      TFTscreen.background(255, 255, 255);
      TFTscreen.fill(255, 255, 255);

    for(i=1; i<16; i++) {
      TFTscreen.setTextSize(i);
      TFTscreen.text("Size", 0 , 0);
      delay(200);
    }
}
